@@ -1,9 +1,9 @@
-#ABSTRACT: Patrons Account Information API command line client
 package App::PAIA;
 use strict;
 use v5.10;
 use parent 'App::Cmd';
-our $VERSION = '0.27'; #VERSION
+
+our $VERSION = '0.28';
 
 sub global_opt_spec {
     ['base|b=s'     => "base URL of PAIA server"],
@@ -25,20 +25,23 @@ sub global_opt_spec {
 }
 
 1;
-
 __END__
 
-=pod
-
 =encoding UTF-8
 
 =head1 NAME
 
 App::PAIA - Patrons Account Information API command line client
 
-=head1 VERSION
+=begin markdown
 
-version 0.27
+# STATUS
+
+[![Build Status](https://travis-ci.org/gbv/App-PAIA.png)](https://travis-ci.org/gbv/App-PAIA)
+[![Coverage Status](https://coveralls.io/repos/gbv/App-PAIA/badge.svg?branch=master)](https://coveralls.io/r/gbv/App-PAIA?branch=master)
+[![Kwalitee Score](http://cpants.cpanauthors.org/dist/App-PAIA.png)](http://cpants.cpanauthors.org/dist/App-PAIA)
+
+=end markdown
 
 =head1 SYNOPSIS
 
@@ -79,13 +82,9 @@ Code repository and issue tracker
 
 =back
 
-=head1 AUTHOR
-
-Jakob Voß
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Jakob Voß.
+Copyright Jakob Voß, 2013-
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
