@@ -1,9 +1,7 @@
-#ABSTRACT: common base class of PAIA client commands
 package App::PAIA::Command;
 use strict;
 use v5.10;
 use App::Cmd::Setup -command;
-our $VERSION = '0.27'; #VERSION
 
 use App::PAIA::Agent;
 use App::PAIA::JSON;
@@ -334,30 +332,14 @@ sub execute {
 }
 
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
 App::PAIA::Command - common base class of PAIA client commands
 
-=head1 VERSION
+=head1 SEE ALSO
 
-version 0.27
-
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+L<App::Cmd::Setup>
 
 =cut
