@@ -1,8 +1,6 @@
-#ABSTRACT: Utility class to read and write JSON files
 package App::PAIA::File;
 use strict;
 use v5.10;
-our $VERSION = '0.27'; #VERSION
 
 use App::PAIA::JSON;
 
@@ -81,35 +79,15 @@ sub purge {
 }
 
 1;
-
 __END__
 
-=pod
-
-=encoding UTF-8
-
 =head1 NAME
 
-App::PAIA::File - Utility class to read and write JSON files
-
-=head1 VERSION
-
-version 0.27
+App::PAIA::File - utility class to read and write JSON files
 
 =head1 DESCRIPTION
 
-This module implements an internal utility class to load and store config and
-session files in JSON format.
-
-=head1 AUTHOR
-
-Jakob Voß
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Jakob Voß.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This module implements an internal utility class to load and store config
+files (C<paia.json>) and session files (C<paia-session.json>) in JSON format.
 
 =cut
